domains = [
  {
    "domain": "google.ad",
    "default_language_code": "ca",
    "default_country_code": "ad",
    "country_name": "Andorra",
  },
  {
    "domain": "google.ae",
    "default_language_code": "ar",
    "default_country_code": "ae",
    "country_name": "United Arab Emirates",
  },
  {
    "domain": "google.al",
    "default_language_code": "sq",
    "default_country_code": "al",
    "country_name": "Albania",
  },
  {
    "domain": "google.am",
    "default_language_code": "hy",
    "default_country_code": "am",
    "country_name": "Armenia",
  },
  {
    "domain": "google.as",
    "default_language_code": "en",
    "default_country_code": "as",
    "country_name": "American Samoa",
  },
  {
    "domain": "google.at",
    "default_language_code": "de",
    "default_country_code": "at",
    "country_name": "Austria",
  },
  {
    "domain": "google.az",
    "default_language_code": "az",
    "default_country_code": "az",
    "country_name": "Azerbaijan",
  },
  {
    "domain": "google.ba",
    "default_language_code": "bs",
    "default_country_code": "ba",
    "country_name": "Bosnia and Herzegovina",
  },
  {
    "domain": "google.be",
    "default_language_code": "nl",
    "default_country_code": "be",
    "country_name": "Belgium",
  },
  {
    "domain": "google.bf",
    "default_language_code": "fr",
    "default_country_code": "bf",
    "country_name": "Burkina Faso",
  },
  {
    "domain": "google.bg",
    "default_language_code": "bg",
    "default_country_code": "bg",
    "country_name": "Bulgaria",
  },
  {
    "domain": "google.bi",
    "default_language_code": "fr",
    "default_country_code": "bi",
    "country_name": "Burundi",
  },
  {
    "domain": "google.bj",
    "default_language_code": "fr",
    "default_country_code": "bj",
    "country_name": "Benin",
  },
  {
    "domain": "google.bs",
    "default_language_code": "en",
    "default_country_code": "bs",
    "country_name": "Bahamas",
  },
  {
    "domain": "google.bt",
    "default_language_code": "bt",
    "default_country_code": "bt",
    "country_name": "Bhutan",
  },
  {
    "domain": "google.by",
    "default_language_code": "be",
    "default_country_code": "by",
    "country_name": "Belarus",
  },
  {
    "domain": "google.ca",
    "default_language_code": "en",
    "default_country_code": "ca",
    "country_name": "Canada",
  },
  {
    "domain": "google.cd",
    "default_language_code": "fr",
    "default_country_code": "cg",
    "country_name": "Democratic Republic of the Congo",
  },
  {
    "domain": "google.cf",
    "default_language_code": "fr",
    "default_country_code": "cf",
    "country_name": "Central African Republic",
  },
  {
    "domain": "google.cg",
    "default_language_code": "fr",
    "default_country_code": "cg",
    "country_name": "Republic of the Congo",
  },
  {
    "domain": "google.ch",
    "default_language_code": "de",
    "default_country_code": "ch",
    "country_name": "Switzerland",
  },
  {
    "domain": "google.ci",
    "default_language_code": "fr",
    "default_country_code": "ci",
    "country_name": "Ivory Coast",
  },
  {
    "domain": "google.cl",
    "default_language_code": "es",
    "default_country_code": "cl",
    "country_name": "Chile",
  },
  {
    "domain": "google.cm",
    "default_language_code": "en",
    "default_country_code": "cm",
    "country_name": "Cameroon",
  },
  {
    "domain": "google.co.ao",
    "default_language_code": "pt",
    "default_country_code": "ao",
    "country_name": "Angola",
  },
  {
    "domain": "google.co.bw",
    "default_language_code": "en",
    "default_country_code": "bw",
    "country_name": "Botswana",
  },
  {
    "domain": "google.co.ck",
    "default_language_code": "en",
    "default_country_code": "ck",
    "country_name": "Cook Islands",
  },
  {
    "domain": "google.co.cr",
    "default_language_code": "es",
    "default_country_code": "cr",
    "country_name": "Costa Rica",
  },
  {
    "domain": "google.co.id",
    "default_language_code": "id",
    "default_country_code": "id",
    "country_name": "Indonesia",
  },
  {
    "domain": "google.co.il",
    "default_language_code": "iw",
    "default_country_code": "il",
    "country_name": "Israel",
  },
  {
    "domain": "google.co.in",
    "default_language_code": "hi",
    "default_country_code": "in",
    "country_name": "India",
  },
  {
    "domain": "google.co.jp",
    "default_language_code": "ja",
    "default_country_code": "jp",
    "country_name": "Japan",
  },
  {
    "domain": "google.co.ke",
    "default_language_code": "en",
    "default_country_code": "ke",
    "country_name": "Kenya",
  },
  {
    "domain": "google.co.kr",
    "default_language_code": "ko",
    "default_country_code": "kr",
    "country_name": "South Korea",
  },
  {
    "domain": "google.co.ls",
    "default_language_code": "en",
    "default_country_code": "ls",
    "country_name": "Lesotho",
  },
  {
    "domain": "google.co.ma",
    "default_language_code": "ar",
    "default_country_code": "ma",
    "country_name": "Morocco",
  },
  {
    "domain": "google.co.mz",
    "default_language_code": "pt",
    "default_country_code": "mz",
    "country_name": "Mozambique",
  },
  {
    "domain": "google.co.nz",
    "default_language_code": "en",
    "default_country_code": "nz",
    "country_name": "New Zealand",
  },
  {
    "domain": "google.co.th",
    "default_language_code": "th",
    "default_country_code": "th",
    "country_name": "Thailand",
  },
  {
    "domain": "google.co.tz",
    "default_language_code": "sw",
    "default_country_code": "tz",
    "country_name": "Tanzania",
  },
  {
    "domain": "google.co.ug",
    "default_language_code": "en",
    "default_country_code": "ug",
    "country_name": "Uganda",
  },
  {
    "domain": "google.co.uk",
    "default_language_code": "en",
    "default_country_code": "uk",
    "country_name": "United Kingdom",
  },
  {
    "domain": "google.co.uz",
    "default_language_code": "uz",
    "default_country_code": "uz",
    "country_name": "Uzbekistan",
  },
  {
    "domain": "google.co.ve",
    "default_language_code": "es",
    "default_country_code": "ve",
    "country_name": "Venezuela",
  },
  {
    "domain": "google.co.vi",
    "default_language_code": "en",
    "default_country_code": "vi",
    "country_name": "United States Virgin Islands",
  },
  {
    "domain": "google.co.za",
    "default_language_code": "af",
    "default_country_code": "za",
    "country_name": "South Africa",
  },
  {
    "domain": "google.co.zm",
    "default_language_code": "en",
    "default_country_code": "zm",
    "country_name": "Zambia",
  },
  {
    "domain": "google.co.zw",
    "default_language_code": "en",
    "default_country_code": "zw",
    "country_name": "Zimbabwe",
  },
  {
    "domain": "google.com",
    "default_language_code": "en",
    "default_country_code": "us",
    "country_name": "United States",
  },
  {
    "domain": "google.com.af",
    "default_language_code": "ps",
    "default_country_code": "af",
    "country_name": "Afghanistan",
  },
  {
    "domain": "google.com.ag",
    "default_language_code": "en",
    "default_country_code": "ag",
    "country_name": "Antigua and Barbuda",
  },
  {
    "domain": "google.com.ai",
    "default_language_code": "en",
    "default_country_code": "ai",
    "country_name": "Anguilla",
  },
  {
    "domain": "google.com.ar",
    "default_language_code": "es",
    "default_country_code": "ar",
    "country_name": "Argentina",
  },
  {
    "domain": "google.com.au",
    "default_language_code": "en",
    "default_country_code": "au",
    "country_name": "Australia",
  },
  {
    "domain": "google.com.bd",
    "default_language_code": "bn",
    "default_country_code": "bd",
    "country_name": "Bangladesh",
  },
  {
    "domain": "google.com.bh",
    "default_language_code": "ar",
    "default_country_code": "bh",
    "country_name": "Bahrain",
  },
  {
    "domain": "google.com.bn",
    "default_language_code": "my",
    "default_country_code": "bn",
    "country_name": "Brunei",
  },
  {
    "domain": "google.com.bo",
    "default_language_code": "es",
    "default_country_code": "bo",
    "country_name": "Bolivia",
  },
  {
    "domain": "google.com.br",
    "default_language_code": "pt",
    "default_country_code": "br",
    "country_name": "Brazil",
  },
  {
    "domain": "google.com.bz",
    "default_language_code": "en",
    "default_country_code": "bz",
    "country_name": "Belize",
  },
  {
    "domain": "google.com.co",
    "default_language_code": "es",
    "default_country_code": "co",
    "country_name": "Colombia",
  },
  {
    "domain": "google.com.cu",
    "default_language_code": "es",
    "default_country_code": "cu",
    "country_name": "Cuba",
  },
  {
    "domain": "google.com.cy",
    "default_language_code": "el",
    "default_country_code": "cy",
    "country_name": "Cyprus",
  },
  {
    "domain": "google.com.do",
    "default_language_code": "es",
    "default_country_code": "do",
    "country_name": "Dominican Republic",
  },
  {
    "domain": "google.com.ec",
    "default_language_code": "es",
    "default_country_code": "ec",
    "country_name": "Ecuador",
  },
  {
    "domain": "google.com.eg",
    "default_language_code": "ar",
    "default_country_code": "eg",
    "country_name": "Egypt",
  },
  {
    "domain": "google.com.et",
    "default_language_code": "am",
    "default_country_code": "et",
    "country_name": "Ethiopia",
  },
  {
    "domain": "google.com.fj",
    "default_language_code": "en",
    "default_country_code": "fj",
    "country_name": "Fiji",
  },
  {
    "domain": "google.com.gh",
    "default_language_code": "en",
    "default_country_code": "gh",
    "country_name": "Ghana",
  },
  {
    "domain": "google.com.gi",
    "default_language_code": "en",
    "default_country_code": "gi",
    "country_name": "Gibraltar",
  },
  {
    "domain": "google.com.gt",
    "default_language_code": "es",
    "default_country_code": "gt",
    "country_name": "Guatemala",
  },
  {
    "domain": "google.com.hk",
    "default_language_code": "en",
    "default_country_code": "hk",
    "country_name": "Hong Kong",
  },
  {
    "domain": "google.com.jm",
    "default_language_code": "en",
    "default_country_code": "jm",
    "country_name": "Jamaica",
  },
  {
    "domain": "google.com.kh",
    "default_language_code": "km",
    "default_country_code": "kh",
    "country_name": "Cambodia",
  },
  {
    "domain": "google.com.kw",
    "default_language_code": "ar",
    "default_country_code": "kw",
    "country_name": "Kuwait",
  },
  {
    "domain": "google.com.lb",
    "default_language_code": "ar",
    "default_country_code": "lb",
    "country_name": "Lebanon",
  },
  {
    "domain": "google.com.ly",
    "default_language_code": "ar",
    "default_country_code": "ly",
    "country_name": "Libya",
  },
  {
    "domain": "google.com.mm",
    "default_language_code": "my",
    "default_country_code": "mm",
    "country_name": "Myanmar",
  },
  {
    "domain": "google.com.mt",
    "default_language_code": "mt",
    "default_country_code": "mt",
    "country_name": "Malta",
  },
  {
    "domain": "google.com.mx",
    "default_language_code": "es",
    "default_country_code": "mx",
    "country_name": "Mexico",
  },
  {
    "domain": "google.com.my",
    "default_language_code": "my",
    "default_country_code": "my",
    "country_name": "Malaysia",
  },
  {
    "domain": "google.com.na",
    "default_language_code": "en",
    "default_country_code": "na",
    "country_name": "Namibia",
  },
  {
    "domain": "google.com.ng",
    "default_language_code": "en",
    "default_country_code": "ng",
    "country_name": "Nigeria",
  },
  {
    "domain": "google.com.ni",
    "default_language_code": "es",
    "default_country_code": "ni",
    "country_name": "Nicaragua",
  },
  {
    "domain": "google.com.np",
    "default_language_code": "ne",
    "default_country_code": "np",
    "country_name": "Nepal",
  },
  {
    "domain": "google.com.om",
    "default_language_code": "ar",
    "default_country_code": "om",
    "country_name": "Oman",
  },
  {
    "domain": "google.com.pa",
    "default_language_code": "es",
    "default_country_code": "pa",
    "country_name": "Panama",
  },
  {
    "domain": "google.com.pe",
    "default_language_code": "es",
    "default_country_code": "pe",
    "country_name": "Peru",
  },
  {
    "domain": "google.com.pg",
    "default_language_code": "en",
    "default_country_code": "pg",
    "country_name": "Papua New Guinea",
  },
  {
    "domain": "google.com.ph",
    "default_language_code": "tl",
    "default_country_code": "ph",
    "country_name": "Philippines",
  },
  {
    "domain": "google.com.pk",
    "default_language_code": "en",
    "default_country_code": "pk",
    "country_name": "Pakistan",
  },
  {
    "domain": "google.com.pr",
    "default_language_code": "es",
    "default_country_code": "pr",
    "country_name": "Puerto Rico",
  },
  {
    "domain": "google.com.py",
    "default_language_code": "es",
    "default_country_code": "py",
    "country_name": "Paraguay",
  },
  {
    "domain": "google.com.qa",
    "default_language_code": "ar",
    "default_country_code": "qa",
    "country_name": "Qatar",
  },
  {
    "domain": "google.com.sa",
    "default_language_code": "ar",
    "default_country_code": "sa",
    "country_name": "Saudi Arabia",
  },
  {
    "domain": "google.com.sb",
    "default_language_code": "en",
    "default_country_code": "sb",
    "country_name": "Solomon Islands",
  },
  {
    "domain": "google.com.sg",
    "default_language_code": "en",
    "default_country_code": "sg",
    "country_name": "Singapore",
  },
  {
    "domain": "google.com.sl",
    "default_language_code": "en",
    "default_country_code": "sl",
    "country_name": "Sierra Leone",
  },
  {
    "domain": "google.com.sv",
    "default_language_code": "es",
    "default_country_code": "sv",
    "country_name": "El Salvador",
  },
  {
    "domain": "google.com.tj",
    "default_language_code": "tg",
    "default_country_code": "tj",
    "country_name": "Tajikistan",
  },
  {
    "domain": "google.com.tr",
    "default_language_code": "tr",
    "default_country_code": "tr",
    "country_name": "Turkey",
  },
  {
    "domain": "google.com.tw",
    "default_language_code": "zh-tw",
    "default_country_code": "tw",
    "country_name": "Taiwan",
  },
  {
    "domain": "google.com.ua",
    "default_language_code": "uk",
    "default_country_code": "ua",
    "country_name": "Ukraine",
  },
  {
    "domain": "google.com.uy",
    "default_language_code": "es",
    "default_country_code": "uy",
    "country_name": "Uruguay",
  },
  {
    "domain": "google.com.vc",
    "default_language_code": "en",
    "default_country_code": "vc",
    "country_name": "Saint Vincent and the Grenadines",
  },
  {
    "domain": "google.com.vn",
    "default_language_code": "vi",
    "default_country_code": "vn",
    "country_name": "Vietnam",
  },
  {
    "domain": "google.cv",
    "default_language_code": "pt",
    "default_country_code": "cv",
    "country_name": "Cape Verde",
  },
  {
    "domain": "google.cz",
    "default_language_code": "cs",
    "default_country_code": "cz",
    "country_name": "Czech Republic",
  },
  {
    "domain": "google.de",
    "default_language_code": "de",
    "default_country_code": "de",
    "country_name": "Germany",
  },
  {
    "domain": "google.dj",
    "default_language_code": "ar",
    "default_country_code": "dj",
    "country_name": "Djibouti",
  },
  {
    "domain": "google.dk",
    "default_language_code": "da",
    "default_country_code": "dk",
    "country_name": "Denmark",
  },
  {
    "domain": "google.dm",
    "default_language_code": "en",
    "default_country_code": "dm",
    "country_name": "Dominica",
  },
  {
    "domain": "google.dz",
    "default_language_code": "ar",
    "default_country_code": "dz",
    "country_name": "Algeria",
  },
  {
    "domain": "google.ee",
    "default_language_code": "et",
    "default_country_code": "ee",
    "country_name": "Estonia",
  },
  {
    "domain": "google.es",
    "default_language_code": "es",
    "default_country_code": "es",
    "country_name": "Spain",
  },
  {
    "domain": "google.fi",
    "default_language_code": "fi",
    "default_country_code": "fi",
    "country_name": "Finland",
  },
  {
    "domain": "google.fm",
    "default_language_code": "en",
    "default_country_code": "fm",
    "country_name": "Micronesia, Federated States of",
  },
  {
    "domain": "google.fr",
    "default_language_code": "fr",
    "default_country_code": "fr",
    "country_name": "France",
  },
  {
    "domain": "google.ga",
    "default_language_code": "fr",
    "default_country_code": "ga",
    "country_name": "Gabon",
  },
  {
    "domain": "google.ge",
    "default_language_code": "ka",
    "default_country_code": "ge",
    "country_name": "Georgia",
  },
  {
    "domain": "google.gl",
    "default_language_code": "kl",
    "default_country_code": "gl",
    "country_name": "Greenland",
  },
  {
    "domain": "google.gm",
    "default_language_code": "en",
    "default_country_code": "gm",
    "country_name": "Gambia",
  },
  {
    "domain": "google.gp",
    "default_language_code": "fr",
    "default_country_code": "gp",
    "country_name": "Guadeloupe",
  },
  {
    "domain": "google.gr",
    "default_language_code": "el",
    "default_country_code": "gr",
    "country_name": "Greece",
  },
  {
    "domain": "google.gy",
    "default_language_code": "en",
    "default_country_code": "gy",
    "country_name": "Guyana",
  },
  {
    "domain": "google.hn",
    "default_language_code": "es",
    "default_country_code": "hn",
    "country_name": "Honduras",
  },
  {
    "domain": "google.hr",
    "default_language_code": "hr",
    "default_country_code": "hr",
    "country_name": "Croatia",
  },
  {
    "domain": "google.ht",
    "default_language_code": "fr",
    "default_country_code": "ht",
    "country_name": "Haiti",
  },
  {
    "domain": "google.hu",
    "default_language_code": "hu",
    "default_country_code": "hu",
    "country_name": "Hungary",
  },
  {
    "domain": "google.ie",
    "default_language_code": "en",
    "default_country_code": "ie",
    "country_name": "Ireland",
  },
  {
    "domain": "google.iq",
    "default_language_code": "ar",
    "default_country_code": "iq",
    "country_name": "Iraq",
  },
  {
    "domain": "google.is",
    "default_language_code": "is",
    "default_country_code": "is",
    "country_name": "Iceland",
  },
  {
    "domain": "google.it",
    "default_language_code": "it",
    "default_country_code": "it",
    "country_name": "Italy",
  },
  {
    "domain": "google.jo",
    "default_language_code": "ar",
    "default_country_code": "jo",
    "country_name": "Jordan",
  },
  {
    "domain": "google.kg",
    "default_language_code": "ky",
    "default_country_code": "kg",
    "country_name": "Kyrgyzstan",
  },
  {
    "domain": "google.ki",
    "default_language_code": "en",
    "default_country_code": "ki",
    "country_name": "Kiribati",
  },
  {
    "domain": "google.kz",
    "default_language_code": "kk",
    "default_country_code": "kz",
    "country_name": "Kazakhstan",
  },
  {
    "domain": "google.la",
    "default_language_code": "lo",
    "default_country_code": "la",
    "country_name": "Laos",
  },
  {
    "domain": "google.li",
    "default_language_code": "de",
    "default_country_code": "li",
    "country_name": "Liechtenstein",
  },
  {
    "domain": "google.lk",
    "default_language_code": "si",
    "default_country_code": "lk",
    "country_name": "Sri Lanka",
  },
  {
    "domain": "google.lt",
    "default_language_code": "lt",
    "default_country_code": "lt",
    "country_name": "Lithuania",
  },
  {
    "domain": "google.lu",
    "default_language_code": "fr",
    "default_country_code": "lu",
    "country_name": "Luxembourg",
  },
  {
    "domain": "google.lv",
    "default_language_code": "lv",
    "default_country_code": "lv",
    "country_name": "Latvia",
  },
  {
    "domain": "google.md",
    "default_language_code": "ro",
    "default_country_code": "md",
    "country_name": "Moldova",
  },
  {
    "domain": "google.mg",
    "default_language_code": "fr",
    "default_country_code": "mg",
    "country_name": "Madagascar",
  },
  {
    "domain": "google.mk",
    "default_language_code": "mk",
    "default_country_code": "mk",
    "country_name": "Macedonia",
  },
  {
    "domain": "google.ml",
    "default_language_code": "fr",
    "default_country_code": "ml",
    "country_name": "Mali",
  },
  {
    "domain": "google.mn",
    "default_language_code": "mn",
    "default_country_code": "mn",
    "country_name": "Mongolia",
  },
  {
    "domain": "google.ms",
    "default_language_code": "en",
    "default_country_code": "ms",
    "country_name": "Montserrat",
  },
  {
    "domain": "google.mu",
    "default_language_code": "en",
    "default_country_code": "mu",
    "country_name": "Mauritius",
  },
  {
    "domain": "google.mv",
    "default_language_code": "mv",
    "default_country_code": "mv",
    "country_name": "Maldives",
  },
  {
    "domain": "google.mw",
    "default_language_code": "en",
    "default_country_code": "mw",
    "country_name": "Malawi",
  },
  {
    "domain": "google.ne",
    "default_language_code": "fr",
    "default_country_code": "ne",
    "country_name": "Niger",
  },
  {
    "domain": "google.nl",
    "default_language_code": "nl",
    "default_country_code": "nl",
    "country_name": "Netherlands",
  },
  {
    "domain": "google.no",
    "default_language_code": "no",
    "default_country_code": "no",
    "country_name": "Norway",
  },
  {
    "domain": "google.nr",
    "default_language_code": "en",
    "default_country_code": "nr",
    "country_name": "Nauru",
  },
  {
    "domain": "google.nu",
    "default_language_code": "en",
    "default_country_code": "nu",
    "country_name": "Niue",
  },
  {
    "domain": "google.pl",
    "default_language_code": "pl",
    "default_country_code": "pl",
    "country_name": "Poland",
  },
  {
    "domain": "google.ps",
    "default_language_code": "ar",
    "default_country_code": "ps",
    "country_name": "Palestine",
  },
  {
    "domain": "google.pt",
    "default_language_code": "pt",
    "default_country_code": "pt",
    "country_name": "Portugal",
  },
  {
    "domain": "google.ro",
    "default_language_code": "ro",
    "default_country_code": "ro",
    "country_name": "Romania",
  },
  {
    "domain": "google.rs",
    "default_language_code": "sr",
    "default_country_code": "rs",
    "country_name": "Serbia",
  },
  {
    "domain": "google.ru",
    "default_language_code": "ru",
    "default_country_code": "ru",
    "country_name": "Russia",
  },
  {
    "domain": "google.rw",
    "default_language_code": "rw",
    "default_country_code": "rw",
    "country_name": "Rwanda",
  },
  {
    "domain": "google.sc",
    "default_language_code": "fr",
    "default_country_code": "sc",
    "country_name": "Seychelles",
  },
  {
    "domain": "google.se",
    "default_language_code": "sv",
    "default_country_code": "se",
    "country_name": "Sweden",
  },
  {
    "domain": "google.sh",
    "default_language_code": "en",
    "default_country_code": "sh",
    "country_name": "Saint Helena, Ascension and Tristan da Cunha",
  },
  {
    "domain": "google.si",
    "default_language_code": "sl",
    "default_country_code": "si",
    "country_name": "Slovenia",
  },
  {
    "domain": "google.sk",
    "default_language_code": "sk",
    "default_country_code": "sk",
    "country_name": "Slovakia",
  },
  {
    "domain": "google.sm",
    "default_language_code": "it",
    "default_country_code": "sm",
    "country_name": "San Marino",
  },
  {
    "domain": "google.sn",
    "default_language_code": "fr",
    "default_country_code": "sn",
    "country_name": "Senegal",
  },
  {
    "domain": "google.so",
    "default_language_code": "so",
    "default_country_code": "so",
    "country_name": "Somalia",
  },
  {
    "domain": "google.sr",
    "default_language_code": "nl",
    "default_country_code": "sr",
    "country_name": "Suriname",
  },
  {
    "domain": "google.td",
    "default_language_code": "ar",
    "default_country_code": "td",
    "country_name": "Chad",
  },
  {
    "domain": "google.tg",
    "default_language_code": "fr",
    "default_country_code": "tg",
    "country_name": "Togo",
  },
  {
    "domain": "google.tk",
    "default_language_code": "en",
    "default_country_code": "tk",
    "country_name": "Tokelau",
  },
  {
    "domain": "google.tl",
    "default_language_code": "pt",
    "default_country_code": "tl",
    "country_name": "Timor-Leste",
  },
  {
    "domain": "google.tm",
    "default_language_code": "tk",
    "default_country_code": "tm",
    "country_name": "Turkmenistan",
  },
  {
    "domain": "google.tn",
    "default_language_code": "ar",
    "default_country_code": "tn",
    "country_name": "Tunisia",
  },
  {
    "domain": "google.to",
    "default_language_code": "en",
    "default_country_code": "to",
    "country_name": "Tonga",
  },
  {
    "domain": "google.tt",
    "default_language_code": "en",
    "default_country_code": "tt",
    "country_name": "Trinidad and Tobago",
  },
  {
    "domain": "google.vg",
    "default_language_code": "en",
    "default_country_code": "vg",
    "country_name": "British Virgin Islands",
  },
  {
    "domain": "google.vu",
    "default_language_code": "vu",
    "default_country_code": "vu",
    "country_name": "Vanuatu",
  },
  {
    "domain": "google.ws",
    "default_language_code": "ws",
    "default_country_code": "ws",
    "country_name": "Samoa",
  },
]