languages = [
  {
    "code": "af",
    "name": "Afrikaans",
  },
  {
    "code": "ak",
    "name": "Akan",
  },
  {
    "code": "sq",
    "name": "Albanian",
  },
  {
    "code": "ws",
    "name": "Samoa",
  },
  {
    "code": "am",
    "name": "Amharic",
  },
  {
    "code": "ar",
    "name": "Arabic",
  },
  {
    "code": "hy",
    "name": "Armenian",
  },
  {
    "code": "az",
    "name": "Azerbaijani",
  },
  {
    "code": "eu",
    "name": "Basque",
  },
  {
    "code": "be",
    "name": "Belarusian",
  },
  {
    "code": "bem",
    "name": "Bemba",
  },
  {
    "code": "bn",
    "name": "Bengali",
  },
  {
    "code": "bh",
    "name": "Bihari",
  },
  {
    "code": "xx-bork",
    "name": "Bork, bork, bork!",
  },
  {
    "code": "bs",
    "name": "Bosnian",
  },
  {
    "code": "br",
    "name": "Breton",
  },
  {
    "code": "bg",
    "name": "Bulgarian",
  },
  {
    "code": "bt",
    "name": "Bhutanese",
  },
  {
    "code": "km",
    "name": "Cambodian",
  },
  {
    "code": "ca",
    "name": "Catalan",
  },
  {
    "code": "chr",
    "name": "Cherokee",
  },
  {
    "code": "ny",
    "name": "Chichewa",
  },
  {
    "code": "zh-cn",
    "name": "Chinese (Simplified)",
  },
  {
    "code": "zh-tw",
    "name": "Chinese (Traditional)",
  },
  {
    "code": "co",
    "name": "Corsican",
  },
  {
    "code": "hr",
    "name": "Croatian",
  },
  {
    "code": "cs",
    "name": "Czech",
  },
  {
    "code": "da",
    "name": "Danish",
  },
  {
    "code": "nl",
    "name": "Dutch",
  },
  {
    "code": "xx-elmer",
    "name": "Elmer Fudd",
  },
  {
    "code": "en",
    "name": "English",
  },
  {
    "code": "eo",
    "name": "Esperanto",
  },
  {
    "code": "et",
    "name": "Estonian",
  },
  {
    "code": "ee",
    "name": "Ewe",
  },
  {
    "code": "fo",
    "name": "Faroese",
  },
  {
    "code": "tl",
    "name": "Filipino",
  },
  {
    "code": "fi",
    "name": "Finnish",
  },
  {
    "code": "fr",
    "name": "French",
  },
  {
    "code": "fy",
    "name": "Frisian",
  },
  {
    "code": "gaa",
    "name": "Ga",
  },
  {
    "code": "gl",
    "name": "Galician",
  },
  {
    "code": "ka",
    "name": "Georgian",
  },
  {
    "code": "de",
    "name": "German",
  },
  {
    "code": "el",
    "name": "Greek",
  },
  {
    "code": "kl",
    "name": "Greenlandic",
  },
  {
    "code": "gn",
    "name": "Guarani",
  },
  {
    "code": "gu",
    "name": "Gujarati",
  },
  {
    "code": "xx-hacker",
    "name": "Hacker",
  },
  {
    "code": "ht",
    "name": "Haitian Creole",
  },
  {
    "code": "ha",
    "name": "Hausa",
  },
  {
    "code": "haw",
    "name": "Hawaiian",
  },
  {
    "code": "iw",
    "name": "Hebrew",
  },
  {
    "code": "hi",
    "name": "Hindi",
  },
  {
    "code": "hu",
    "name": "Hungarian",
  },
  {
    "code": "is",
    "name": "Icelandic",
  },
  {
    "code": "ig",
    "name": "Igbo",
  },
  {
    "code": "id",
    "name": "Indonesian",
  },
  {
    "code": "ia",
    "name": "Interlingua",
  },
  {
    "code": "ga",
    "name": "Irish",
  },
  {
    "code": "it",
    "name": "Italian",
  },
  {
    "code": "ja",
    "name": "Japanese",
  },
  {
    "code": "jw",
    "name": "Javanese",
  },
  {
    "code": "kn",
    "name": "Kannada",
  },
  {
    "code": "kk",
    "name": "Kazakh",
  },
  {
    "code": "rw",
    "name": "Kinyarwanda",
  },
  {
    "code": "rn",
    "name": "Kirundi",
  },
  {
    "code": "xx-klingon",
    "name": "Klingon",
  },
  {
    "code": "kg",
    "name": "Kongo",
  },
  {
    "code": "ko",
    "name": "Korean",
  },
  {
    "code": "kri",
    "name": "Krio (Sierra Leone)",
  },
  {
    "code": "ku",
    "name": "Kurdish",
  },
  {
    "code": "ckb",
    "name": "Kurdish (Soranî)",
  },
  {
    "code": "ky",
    "name": "Kyrgyz",
  },
  {
    "code": "lo",
    "name": "Laothian",
  },
  {
    "code": "la",
    "name": "Latin",
  },
  {
    "code": "lv",
    "name": "Latvian",
  },
  {
    "code": "ln",
    "name": "Lingala",
  },
  {
    "code": "lt",
    "name": "Lithuanian",
  },
  {
    "code": "loz",
    "name": "Lozi",
  },
  {
    "code": "lg",
    "name": "Luganda",
  },
  {
    "code": "ach",
    "name": "Luo",
  },
  {
    "code": "mk",
    "name": "Macedonian",
  },
  {
    "code": "mg",
    "name": "Malagasy",
  },
  {
    "code": "my",
    "name": "Malay",
  },
  {
    "code": "ml",
    "name": "Malayalam",
  },
  {
    "code": "mt",
    "name": "Maltese",
  },
  {
    "code": "mv",
    "name": "Maldives",
  },
  {
    "code": "mi",
    "name": "Maori",
  },
  {
    "code": "mr",
    "name": "Marathi",
  },
  {
    "code": "mfe",
    "name": "Mauritian Creole",
  },
  {
    "code": "mo",
    "name": "Moldavian",
  },
  {
    "code": "mn",
    "name": "Mongolian",
  },
  {
    "code": "sr-me",
    "name": "Montenegrin",
  },
  {
    "code": "ne",
    "name": "Nepali",
  },
  {
    "code": "pcm",
    "name": "Nigerian Pidgin",
  },
  {
    "code": "nso",
    "name": "Northern Sotho",
  },
  {
    "code": "no",
    "name": "Norwegian",
  },
  {
    "code": "nn",
    "name": "Norwegian (Nynorsk)",
  },
  {
    "code": "oc",
    "name": "Occitan",
  },
  {
    "code": "or",
    "name": "Oriya",
  },
  {
    "code": "om",
    "name": "Oromo",
  },
  {
    "code": "ps",
    "name": "Pashto",
  },
  {
    "code": "fa",
    "name": "Persian",
  },
  {
    "code": "xx-pirate",
    "name": "Pirate",
  },
  {
    "code": "pl",
    "name": "Polish",
  },
  {
    "code": "pt",
    "name": "Portuguese",
  },
  {
    "code": "pt-br",
    "name": "Portuguese (Brazil)",
  },
  {
    "code": "pt-pt",
    "name": "Portuguese (Portugal)",
  },
  {
    "code": "pa",
    "name": "Punjabi",
  },
  {
    "code": "qu",
    "name": "Quechua",
  },
  {
    "code": "ro",
    "name": "Romanian",
  },
  {
    "code": "rm",
    "name": "Romansh",
  },
  {
    "code": "nyn",
    "name": "Runyakitara",
  },
  {
    "code": "ru",
    "name": "Russian",
  },
  {
    "code": "gd",
    "name": "Scots Gaelic",
  },
  {
    "code": "sr",
    "name": "Serbian",
  },
  {
    "code": "sh",
    "name": "Serbo-Croatian",
  },
  {
    "code": "st",
    "name": "Sesotho",
  },
  {
    "code": "tn",
    "name": "Setswana",
  },
  {
    "code": "crs",
    "name": "Seychellois Creole",
  },
  {
    "code": "sn",
    "name": "Shona",
  },
  {
    "code": "sd",
    "name": "Sindhi",
  },
  {
    "code": "si",
    "name": "Sinhalese",
  },
  {
    "code": "sk",
    "name": "Slovak",
  },
  {
    "code": "sl",
    "name": "Slovenian",
  },
  {
    "code": "so",
    "name": "Somali",
  },
  {
    "code": "es",
    "name": "Spanish",
  },
  {
    "code": "es-419",
    "name": "Spanish (Latin American)",
  },
  {
    "code": "su",
    "name": "Sundanese",
  },
  {
    "code": "sw",
    "name": "Swahili",
  },
  {
    "code": "sv",
    "name": "Swedish",
  },
  {
    "code": "tg",
    "name": "Tajik",
  },
  {
    "code": "ta",
    "name": "Tamil",
  },
  {
    "code": "tt",
    "name": "Tatar",
  },
  {
    "code": "te",
    "name": "Telugu",
  },
  {
    "code": "th",
    "name": "Thai",
  },
  {
    "code": "ti",
    "name": "Tigrinya",
  },
  {
    "code": "to",
    "name": "Tonga",
  },
  {
    "code": "lua",
    "name": "Tshiluba",
  },
  {
    "code": "tum",
    "name": "Tumbuka",
  },
  {
    "code": "tr",
    "name": "Turkish",
  },
  {
    "code": "tk",
    "name": "Turkmen",
  },
  {
    "code": "tw",
    "name": "Twi",
  },
  {
    "code": "ug",
    "name": "Uighur",
  },
  {
    "code": "uk",
    "name": "Ukrainian",
  },
  {
    "code": "ur",
    "name": "Urdu",
  },
  {
    "code": "uz",
    "name": "Uzbek",
  },
  {
    "code": "vu",
    "name": "Vanuatu",
  },
  {
    "code": "vi",
    "name": "Vietnamese",
  },
  {
    "code": "cy",
    "name": "Welsh",
  },
  {
    "code": "wo",
    "name": "Wolof",
  },
  {
    "code": "xh",
    "name": "Xhosa",
  },
  {
    "code": "yi",
    "name": "Yiddish",
  },
  {
    "code": "yo",
    "name": "Yoruba",
  },
  {
    "code": "zu",
    "name": "Zulu",
  },
]