languages = [
  { 'text': 'English', 'code': 'en_US' },
  { 'text': 'español', 'code': 'es_US' },
  { 'text': 'العربية', 'code': 'ar_AE' },
  { 'text': 'Deutsch', 'code': 'de_DE' },
  { 'text': 'עברית', 'code': 'he_IL' },
  { 'text': '한국어', 'code': 'ko_KR' },
  { 'text': 'português', 'code': 'pt_BR' },
  { 'text': '中文 (简体)', 'code': 'zh_CN' },
  { 'text': '中文 (繁體)', 'code': 'zh_TW' },
]