domains = [
  { 'domain': 'ebay.com.au', 'country': 'Australia' },
  { 'domain': 'ebay.at', 'country': 'Austria' },
  { 'domain': 'ebay.ca', 'country': 'Canada' },
  { 'domain': 'ebay.fr', 'country': 'France' },
  { 'domain': 'ebay.de', 'country': 'Germany' },
  { 'domain': 'ebay.com.hk', 'country': 'Hong Kong' },
  { 'domain': 'ebay.ie', 'country': 'Ireland' },
  { 'domain': 'ebay.it', 'country': 'Italy' },
  { 'domain': 'ebay.com.my', 'country': 'Malaysia' },
  { 'domain': 'ebay.nl', 'country': 'Netherlands' },
  { 'domain': 'ebay.ph', 'country': 'Philippines' },
  { 'domain': 'ebay.pl', 'country': 'Poland' },
  { 'domain': 'ebay.com.sg', 'country': 'Singapore' },
  { 'domain': 'ebay.es', 'country': 'Spain' },
  { 'domain': 'ebay.ch', 'country': 'Switzerland' },
  { 'domain': 'ebay.co.uk', 'country': 'United Kingdom' },
  { 'domain': 'ebay.com', 'country': 'United States' },
]