currencies = [
  { 'text': 'US Dollar', 'code': 'USD' },
  { 'text': 'Chilean Peso', 'code': 'CLP' },
  { 'text': 'Colombian Peso', 'code': 'COP' },
  { 'text': 'Hong Kong Dollar', 'code': 'HKD' },
  { 'text': 'Indonesian Rupiah', 'code': 'IDR' },
  { 'text': 'Israeli New Shekel', 'code': 'ILS' },
  { 'text': 'South Korean Won', 'code': 'KRW' },
  { 'text': 'Malaysian Ringgit', 'code': 'MYR' },
  { 'text': 'New Zealand Dollar', 'code': 'NZD' },
  { 'text': 'Thai Baht', 'code': 'THB' },
  { 'text': 'New Taiwan Dollar', 'code': 'TWD' },
  { 'text': 'Costa Rican Colón', 'code': 'CRC' },
  { 'text': 'Peruvian Sol', 'code': 'PEN' },
  { 'text': 'Uruguayan Peso', 'code': 'UYU' },
  { 'text': 'Brazilian Real', 'code': 'BRL' },
  { 'text': 'Australian Dollar', 'code': 'AUD' },
  { 'text': 'Canadian Dollar', 'code': 'CAD' },
  { 'text': 'Chinese Yuan', 'code': 'CNY' },
  { 'text': 'Euro', 'code': 'EUR' },
  { 'text': 'Japanese Yen', 'code': 'JPY' },
  { 'text': 'Mexican Peso', 'code': 'MXN' },
  { 'text': 'British Pound', 'code': 'GBP' },
  { 'text': 'United Arab Emirates Dirham', 'code': 'AED' },
  { 'text': 'Singapore Dollar', 'code': 'SGD' },
  { 'text': 'Saudi Riyal', 'code': 'SAR' },
  { 'text': 'Norwegian Krone', 'code': 'NOK' },
  { 'text': 'Argentine Peso', 'code': 'ARS' },
  { 'text': 'Armenian Dram', 'code': 'AMD' },
  { 'text': 'Aruban Florin', 'code': 'AWG' },
  { 'text': 'Azerbaijani Manat', 'code': 'AZN' },
  { 'text': 'Bahamian Dollar', 'code': 'BSD' },
  { 'text': 'Belize Dollar', 'code': 'BZD' },
  { 'text': 'Bolivian Boliviano', 'code': 'BOB' },
  { 'text': 'Brunei Dollar', 'code': 'BND' },
  { 'text': 'Bulgarian Lev', 'code': 'BGN' },
  { 'text': 'Cambodian Riel', 'code': 'KHR' },
  { 'text': 'Cayman Islands Dollar', 'code': 'KYD' },
  { 'text': 'Dominican Peso', 'code': 'DOP' },
  { 'text': 'East Caribbean Dollar', 'code': 'XCD' },
  { 'text': 'Egyptian Pound', 'code': 'EGP' },
  { 'text': 'Ghanaian Cedi', 'code': 'GHS' },
  { 'text': 'Guatemalan Quetzal', 'code': 'GTQ' },
  { 'text': 'Hungarian Forint', 'code': 'HUF' },
  { 'text': 'Indian Rupee', 'code': 'INR' },
  { 'text': 'Jamaican Dollar', 'code': 'JMD' },
  { 'text': 'Kazakhstani Tenge', 'code': 'KZT' },
  { 'text': 'Kenyan Shilling', 'code': 'KES' },
  { 'text': 'Lebanese Pound', 'code': 'LBP' },
  { 'text': 'Honduran Lempira', 'code': 'HNL' },
  { 'text': 'Macanese Pataca', 'code': 'MOP' },
  { 'text': 'Mauritian Rupee', 'code': 'MUR' },
  { 'text': 'Moroccan Dirham', 'code': 'MAD' },
  { 'text': 'Namibian Dollar', 'code': 'NAD' },
  { 'text': 'Nigerian Naira', 'code': 'NGN' },
  { 'text': 'Panamanian Balboa', 'code': 'PAB' },
  { 'text': 'Paraguayan Guarani', 'code': 'PYG' },
  { 'text': 'Qatari Riyal', 'code': 'QAR' },
  { 'text': 'Russian Ruble', 'code': 'RUB' },
  { 'text': 'South African Rand', 'code': 'ZAR' },
  { 'text': 'Tanzanian Shilling', 'code': 'TZS' },
  { 'text': 'Philippine Peso', 'code': 'PHP' },
  { 'text': 'Trinidad & Tobago Dollar', 'code': 'TTD' },
  { 'text': 'Mongolian Tugrik', 'code': 'MNT' },
  { 'text': 'Turkish Lira', 'code': 'TRY' },
  { 'text': 'Vietnamese Dong', 'code': 'VND' },
  { 'text': 'Swedish Krona', 'code': 'SEK' },
  { 'text': 'Polish Zloty', 'code': 'PLN' },
]